/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.dialog.config;

import javax.servlet.ServletContext;

import org.apache.commons.chain.Command;
import org.apache.commons.chain.Context;
import org.apache.shale.dialog.Globals;

/**
 * <p>Command executed at web application shutdown to clean up the
 * configured resources for the dialogs configuration.</p>
 *
 * $Id: ConfigurationDestroy.java 419431 2006-07-06 04:38:39Z wsmoak $
 */
public class ConfigurationDestroy implements Command {


    /**
     * <p>Clean up configuration resources.</p>
     *
     * @param context Execution context for this command
     *
     * @exception Exception if an executed command throws an Exception
     */
    public boolean execute(Context context) throws Exception {

        // Remove the application scope resources we created
        ServletContext scontext = (ServletContext) context.get("context");
        scontext.removeAttribute(Globals.DIALOGS);

        // Allow other cleanup activities to proceed
        return false;

    }


}
