/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.dialog.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.shale.dialog.State;
import org.apache.shale.dialog.Transition;

/**
 * <p>{@link TransitionImpl} is a basic implementation of
 * {@link Transition}.</p>
 *
 * $Id: TransitionImpl.java 419431 2006-07-06 04:38:39Z wsmoak $
 */

public class TransitionImpl implements Transition {


    // ------------------------------------------------------ Instance Variables


    /**
     * <p><code>Log</code> instance for this instance.</p>
     */
    protected final Log log = LogFactory.getLog(getClass());


    /**
     * <p>The logical outcome used to select this {@link Transition}.</p>
     */
    private String outcome = null;


    /**
     * <p>The identifier of the target {@link State} for this
     * {@link Transition}.</p>
     */
    private String target = null;


    // -------------------------------------------------------------- Properties


    /**
     * {@inheritDoc}
     */
    public String getOutcome() {

        return this.outcome;

    }


    /**
     * {@inheritDoc}
     */
    public String getTarget() {

        return this.target;

    }


    // ---------------------------------------------------------- Public Methods


    /**
     * <p>Render a printable version of this instance.</p>
     */
    public String toString() {

        return "Transition[outcome=" + this.outcome +
               ",target=" + this.target + "]";

    }


    // --------------------------------------------------- Configuration Methods


    /**
     * <p>Set the logical outcome used to select this {@link Transition}.</p>
     *
     * @param outcome New logical outcome
     */
    public void setOutcome(String outcome) {

        this.outcome = outcome;

    }


    /**
     * <p>Set the target {@link State} identifier for this
     * {@link Transition}.</p>
     *
     * @param target New target identifier
     */
    public void setTarget(String target) {

        this.target = target;

    }


}
