/*
 * Copyright 2004-2005 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.remote;

import javax.faces.model.SelectItem;

/**
 * <p>Simple concrete subclass of {@link AbstractSelectItems} that
 * assumes the array of <code>SelectItem</code> instances to be used
 * has been stored in a specified context key.  The value of the context
 * key to be used may be configured by calling <code>setAttributeKey()</code>,
 * and defaults to the value of the manifest constant <code>ATTRIBUTE_KEY</code>.</p>
 *
 * @deprecated Use corresponding functionality from the
 *  <code>org.apache.shale.remoting</code> package
 *
 * $Id: BasicSelectItems.java 419431 2006-07-06 04:38:39Z wsmoak $
 */

public class BasicSelectItems extends AbstractSelectItems {
    
    
    // -------------------------------------------------------- Static Variables


    /**
     * <p>Default attribute key under which we will look for an array
     * of <code>SelectItem</code> instances.</p>
     */
    public static final String ATTRIBUTE_KEY = "selectItems";
    

    // ------------------------------------------------------ Instance Variables


    // -------------------------------------------------------------- Properties


    /**
     * <p>The attribute key used to look up the <code>SelectItem</code>s array.</p>
     */
    private String attributeKey = ATTRIBUTE_KEY;


    /**
     * <p>Return the attribute key used to look up the <code>SelectItem</code>s
     * array.</p>
     */
    public String getAttributeKey() {

        return attributeKey;

    }


    /**
     * <p>Set the attribute key used to look up the <code>SelectItem</code>s
     * array.</p>
     *
     * @param attributeKey The new attribute key
     */
    public void setAttributeKey(String attributeKey) {

        this.attributeKey = attributeKey;

    }


    // --------------------------------------------- AbstractSelectItems Methods


    /**
     * <p>Return the (possibly empty) set of legal items that are currently
     * available, based on the specified test string.  This method is used
     * by the default implementation of <code>match()</code>, but may be
     * made unnecessary by a custom implementation of that method.</p>
     *
     * <p>The default implementation expects a context attribute named
     * by the value returned by <code>getAttributeKey()</code> to contain
     * an array of <code>SelectItem</code> instances.  If there is no such
     * defined attribute (or if it is not of type <code>SelectItem[]</code>),
     * a zero-length array will be returned.</p>
     *
     * @param context {@link RemoteContext} for this request
     * @param test Test value optionally used to select legal values
     */
    protected SelectItem[] legal(RemoteContext context, String test) {

        try {
            SelectItem items[] = (SelectItem[]) context.get(getAttributeKey());
            if (items == null) {
                items = new SelectItem[0];
            }
            return items;
        } catch (ClassCastException e) {
            return new SelectItem[0];
        }

    }


}
