/*
 * Copyright 2004-2005 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.remote;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

import org.apache.commons.chain.Command;
import org.apache.commons.chain.Context;

/**
 * <p>Evaluate the specified value binding expression, and store the resulting
 * value as a context attribute under the specified attribute key.</p>
 *
 * @deprecated Use corresponding functionality from the
 *  <code>org.apache.shale.remoting</code> package
 *
 * $Id: EvaluateExpression.java 419431 2006-07-06 04:38:39Z wsmoak $
 */

public class EvaluateExpression implements Command {
    
    
    // -------------------------------------------------------------- Properties


    /**
     * <p>The attribute key used to store the evaluated expression value.</p>
     */
    private String attributeKey = null;


    /**
     * <p>Return the attribute key used to store the evaluated expression
     * value.</p>
     */
    public String getAttributeKey() {

        return attributeKey;

    }


    /**
     * <p>Set the attribute key used to store the evaluated expression
     * value.</p>
     *
     * @param attributeKey The new attribute key
     */
    public void setAttributeKey(String attributeKey) {

        this.attributeKey = attributeKey;

    }


    /**
     * <p>The value binding expression (including delimiters) to be evaluated.</p>
     */
    private String expression = null;


    /**
     * <p>Return the value binding expression (including delimiters) to be
     * evaluated.</p>
     */
    public String getExpression() {

        return this.expression;

    }


    /**
     * <p>Set the value binding expression (including delimiters) to be
     * evaluated.</p>
     *
     * @param expression The new value binding expression (including delimiters)
     */
    public void setExpression(String expression) {

        this.expression = expression;

    }


    // --------------------------------------------------------- Command Methods


    /**
     * <p>Evaluate the specified expression, and store the result in the
     * specified attribute.  Return <code>false</code> so that the
     * current chain will continue.</p>
     *
     * @param context <code>Context</code> for the current request
     *
     * @exception Exception if an exception is thrown during execution
     */
    public boolean execute(Context context) throws Exception {

        FacesContext fcontext = FacesContext.getCurrentInstance();
        ValueBinding vb = fcontext.getApplication().createValueBinding(getExpression());
        context.put(getAttributeKey(), vb.getValue(fcontext));
        return false; // Let the current chain continue

    }


}
